@@ -21,28 +21,15 @@
 #include "gconf-internals.h"
 #include "gconf-sources.h"
 #include "gconf-backend.h"
+#include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
-#include <popt.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <fcntl.h>
 
-struct poptOption options[] = {
-  POPT_AUTOHELP
-  {
-    NULL,
-    '\0',
-    0,
-    NULL,
-    0,
-    NULL,
-    NULL
-  }
-};
-
 static gboolean ensure_gtk (void);
 static void     show_fatal_error_dialog (const char *format,
                                          ...) G_GNUC_PRINTF (1, 2);
@@ -53,28 +40,27 @@ static gboolean check_gconf (gboolean display_errors);
 int 
 main (int argc, char** argv)
 {
-  poptContext ctx;
-  gint nextopt;
-  
-  ctx = poptGetContext ("gconf-sanity-check-2", argc, (const char **) argv, options, 0);
+  GOptionContext *context;
+  GError *error;
 
-  poptReadDefaultConfig (ctx, TRUE);
+  g_thread_init (NULL);
 
-  while ((nextopt = poptGetNextOpt(ctx)) > 0)
-    /*nothing*/;
+  context = g_option_context_new (_("- Sanity checks for GConf"));
+  g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
-  if (nextopt != -1) 
+  error = NULL;
+  g_option_context_parse (context, &argc, &argv, &error);
+  g_option_context_free (context);
+
+  if (error)
     {
-      g_printerr (_("Error on option %s: %s.\nRun '%s --help' to see a full list of available command line options.\n"),
-                  poptBadOption(ctx, 0),
-                  poptStrerror(nextopt),
+      g_printerr (_("Error while parsing options: %s.\nRun '%s --help' to see a full list of available command line options.\n"),
+                  error->message,
                   argv[0]);
-      poptFreeContext (ctx);
+      g_error_free (error);
       return 1;
     }
 
-  poptFreeContext (ctx);
-
   if (!check_file_locking ())
     return 1;
 
@@ -158,9 +144,9 @@ check_file_locking (void)
                                    NULL);
       
       /* keep the open from failing due to non-writable old file or something */
-      unlink (testfile);
+      g_unlink (testfile);
   
-      fd = open (testfile, O_WRONLY | O_CREAT, 0700);
+      fd = g_open (testfile, O_WRONLY | O_CREAT, 0700);
 
       if (fd < 0)
         {      
@@ -169,7 +155,7 @@ check_file_locking (void)
                                      "that there may be a problem with your configuration, "
                                      "as many programs will need to create files in your "
                                      "home directory. The error was \"%s\" (errno = %d)."),
-                                   testfile, strerror (errno), errno);
+                                   testfile, g_strerror (errno), errno);
           
           goto out;
         }
@@ -186,7 +172,7 @@ check_file_locking (void)
                                  "See the rpc.statd and rpc.lockd documentation. "
                                  "A common cause of this error is that the \"nfslock\" service has been disabled."
                                  "The error was \"%s\" (errno = %d)."),
-                               testfile, strerror (errno), errno); 
+                               testfile, g_strerror (errno), errno); 
       goto out;
     }
 
@@ -194,8 +180,8 @@ check_file_locking (void)
 
  out:
   close (fd);
-  if (unlink (testfile) < 0)
-    g_printerr (_("Can't remove file %s: %s\n"), testfile, strerror (errno));
+  if (g_unlink (testfile) < 0)
+    g_printerr (_("Can't remove file %s: %s\n"), testfile, g_strerror (errno));
   g_free (testfile);
   
   return retval;
@@ -223,7 +209,7 @@ check_gconf (gboolean display_errors)
       goto out;
     }
   
-  conffile = g_strconcat (GCONF_CONFDIR, "/path", NULL);
+  conffile = g_build_filename (GCONF_CONFDIR, "path", NULL);
 
   error = NULL;
   addresses = gconf_load_source_path (conffile, &error);
@@ -370,7 +356,7 @@ offer_delete_locks (void)
       GSList* tmp;
       char *conffile;
       
-      conffile = g_strconcat (GCONF_CONFDIR, "/path", NULL);
+      conffile = g_build_filename (GCONF_CONFDIR, "path", NULL);
       
       addresses = gconf_load_source_path (conffile, NULL);
 
